@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import pickle
+from base64 import b85encode, b85decode
 from pathlib import Path
 
 import luigi as lg
@@ -20,26 +22,29 @@ from luigi.task import flatten
 
 from .data import Target
 
-class WhateverParameter(lg.Parameter):
-    def _warn_on_wrong_param_type(self, param_name, param_value):
-        return
-
 class PathParameter(lg.PathParameter):
     def _warn_on_wrong_param_type(self, param_name, param_value):
         Path(param_value)
 
-    def serialize(self, x):
+    def serializeShort(self, x):
         pathForShow = Path(x)
         if pathForShow.is_absolute():
             if pathForShow.is_relative_to(Path.cwd()):
                 pathForShow = pathForShow.relative_to(Path.cwd())
         return str(pathForShow)
 
-class TaskParameter(lg.Parameter):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+class WhateverParameter(lg.Parameter):
+    def _warn_on_wrong_param_type(self, param_name, param_value):
+        return
 
     def serialize(self, x):
+        return str(b85encode(pickle.dumps(x)), encoding='ASCII')
+
+    def parse(self, x):
+        return pickle.loads(b85decode(bytes(x, encoding='ASCII')))
+
+class TaskParameter(WhateverParameter):
+    def serializeShort(self, x):
         try:
             return x.output().pathRel
         except:
@@ -48,11 +53,8 @@ class TaskParameter(lg.Parameter):
             except:
                 return super().serialize(x)
 
-class TaskListParameter(lg.Parameter):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    def serialize(self, xs):
+class TaskListParameter(WhateverParameter):
+    def serializeShort(self, xs):
         try:
             return ';'.join(sorted([x.output().pathRel for x in xs]))
         except:
@@ -61,18 +63,27 @@ class TaskListParameter(lg.Parameter):
             except:
                 return super().serialize(xs)
 
-class TargetParameter(lg.Parameter):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def serialize(self, x):
+        return str(b85encode(pickle.dumps(x)), encoding='ASCII')
 
+    def parse(self, x):
+        return pickle.loads(b85decode(bytes(x, encoding='ASCII')))
+
+class TargetParameter(WhateverParameter):
     def _warn_on_wrong_param_type(self, param_name, param_value):
         if self.__class__ != TargetParameter:
             return
         if not isinstance(param_value, Target):
             raise ValueError("parameter {} must be a Eikthyr target, got {} instead".format(param_name, param_value))
 
-    def serialize(self, x):
+    def serializeShort(self, x):
         try:
             return x.pathRel
         except:
             return super().serialize(x)
+
+    def serialize(self, x):
+        return str(b85encode(pickle.dumps(x)), encoding='ASCII')
+
+    def parse(self, x):
+        return pickle.loads(b85decode(bytes(x, encoding='ASCII')))
