@@ -16,7 +16,7 @@
 import time
 import pickle
 from hashlib import md5
-from inspect import getsource
+from inspect import getsource, isgenerator
 from pathlib import Path
 
 import luigi as lg
@@ -47,10 +47,28 @@ class Task(lg.Task):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.objOutput = self.generates()
+        self.objOutput = None
         self._cacheComplete = None
         self._hashSrc = None
 
+    # Mostly copied from the original luigi
+    def __repr__(self):
+        params = self.get_params()
+        param_values = self.get_param_values(params, [], self.param_kwargs)
+
+        # Build up task id
+        repr_parts = []
+        param_objs = dict(params)
+        for param_name, param_value in param_values:
+            if param_objs[param_name].significant:
+                if hasattr(param_objs[param_name], 'serializeShort'):
+                    thisRepr = param_objs[param_name].serializeShort(param_value)
+                else:
+                    thisRepr = param_objs[param_name].serialize(param_value)
+                repr_parts.append('{}={}'.format(param_name, thisRepr))
+
+        return '{}({})'.format(self.get_task_family(), ', '.join(repr_parts))
+
     def _requires(self):
         return flatten(self.requires()) + list(self.prev)
 
@@ -69,6 +87,8 @@ class Task(lg.Task):
             return []
 
     def output(self):
+        if self.objOutput == None:
+            self.objOutput = self.generates()
         return self.objOutput;
 
     def getSignature(self):
@@ -97,6 +117,8 @@ class Task(lg.Task):
             self.timeStart = time.time()
         with withEnv(**self.environ):
             rtn = self.task()
+            if isgenerator(rtn):
+                yield from rtn
         self.invalidateCache()
         logger.info("End {} in {:.3f}s\n".format(self, time.time() - self.timeStart))
         return rtn
